@@ -1,10 +1,11 @@
 use crate::units::Units;
 
-#[derive(Debug)]
+#[derive(Clone, Debug)]
 pub struct Options {
     pub units: Option<Units>,
     pub connect_timeout: Option<u64>,
     pub timeout: Option<u64>,
+    pub query: Option<String>,
     pub full_info: Option<bool>,
     pub silent: Option<bool>,
     pub version: Option<String>,
